@@ -40,8 +40,6 @@ from notebook.services.contents.manager import (
     ContentsManager,
 )
 
-# from .cortx_jupyter import JupyterS3
-# from .cortx_jupyter import CortxJupyterSecretAccessKeyAuthentication
 
 DIRECTORY_SUFFIX = '/'
 NOTEBOOK_SUFFIX = '.ipynb'
@@ -720,7 +718,6 @@ def _list_keys(context, key_prefix, delimiter):
 
     @gen.coroutine
     def _list_first_page():
-        print(type(context.s3_bucket))
         response = _list_objects(context, context.s3_bucket, key_prefix, delimiter, max_keys)
 
         return _parse_list_response(response)
@@ -849,7 +846,7 @@ def _delete_object(context, bucket, file_name):
                              aws_secret_access_key=credentials.aws_secret_access_key, region_name='us-east-1', endpoint_url="https://s3.amazonaws.com")
     return s3_client.delete_object(Bucket=bucket, Key=file_name)
 
-
+@gen.coroutine
 def _list_objects(context, bucket, prefix, delimiter, max_keys, token=''):
     credentials = yield context.s3_auth()
     print(credentials)
@@ -860,4 +857,4 @@ def _list_objects(context, bucket, prefix, delimiter, max_keys, token=''):
         Delimiter=delimiter,
         MaxKeys=max_keys,
         Prefix=prefix,
-        ContinuationToken='')
+        ContinuationToken=token)
